Changelog of threedi-scenario-downloader
===================================================


0.2 (2019-01-24)
----------------

- Added automatic deploys to
  https://pypi.org/project/threedi-scenario-downloader/


0.1 (2019-01-23)
----------------

- Initial project structure created with cookiecutter and
  https://github.com/nens/cookiecutter-python-template

- Initial working version.
